@@ -154,6 +154,8 @@ pub mod paginated_octo_print_event_list;
 pub use self::paginated_octo_print_event_list::PaginatedOctoPrintEventList;
 pub mod paginated_onboarding_task_list;
 pub use self::paginated_onboarding_task_list::PaginatedOnboardingTaskList;
+pub mod paginated_polymorphic_event_list;
+pub use self::paginated_polymorphic_event_list::PaginatedPolymorphicEventList;
 pub mod paginated_print_job_event_list;
 pub use self::paginated_print_job_event_list::PaginatedPrintJobEventList;
 pub mod paginated_print_nanny_plugin_event_list;
@@ -212,6 +214,10 @@ pub mod patched_system_info_request;
 pub use self::patched_system_info_request::PatchedSystemInfoRequest;
 pub mod patched_user_request;
 pub use self::patched_user_request::PatchedUserRequest;
+pub mod polymorphic_event;
+pub use self::polymorphic_event::PolymorphicEvent;
+pub mod polymorphic_event_request;
+pub use self::polymorphic_event_request::PolymorphicEventRequest;
 pub mod print_job_event;
 pub use self::print_job_event::PrintJobEvent;
 pub mod print_job_event_request;
